Arequest Helper
Бібліотека для швидкої взаємодії із asyncio, aiohttp з додатковим функціоналом вібправлення повідомлень в бота. 
Підійде для своїх проектів з використанням асинхронності.

to install use 
pip install arequestsHelper

